@@ -4,13 +4,16 @@ use 5.008;
 use strict;
 use overload '""' => 'stringify';
 
-our $VERSION = '0.59';
+our $VERSION = '0.61';
 
 require XSLoader;
+sub DynaLoader::mod2fname {$_[0]->[-1].'1'} # we have 'ecl1.dll' to avoid confusion (or to bring one)
 XSLoader::load('ecl', $VERSION);
+undef &DynaLoader::mod2fname;
 
 sub new {
     cl_boot();
+    #_eval("");
     return bless {}, __PACKAGE__;
 }
 
@@ -41,6 +44,7 @@ sub stringify {
 my %meth;
 
 sub vivify_lisp_method {
+    print STDERR "[[debug, vivify_lisp_method:@_]]\n";
     my ($package, $method) = @_;
     my $method0;
     for ($method) {
@@ -250,6 +254,10 @@ to the 'keyword' package. These keywords correspond to lisp's C<:keywords>.
 given lisp object blessed to package ecl::Code calls the
 procedure.
 
+=head3 other way round: perl-ev
+
+ (prin1 (perl-ev "join (',','a'..'z'). qq/hello!/" ) )
+
 =head2 AUTOLOADing
 
 $cl->someFunctionName(args) get transformed into function call to
